==> kumactl-2.4.2.tar.gz: kuma-2.4.2/test/e2e_env/kubernetes/inspect/inspect.go <==
package inspect

import (
	"fmt"

	. "github.com/onsi/ginkgo/v2"
	. "github.com/onsi/gomega"

	. "github.com/kumahq/kuma/test/framework"
	"github.com/kumahq/kuma/test/framework/deployments/democlient"
	"github.com/kumahq/kuma/test/framework/envs/kubernetes"
)

func Inspect() {
	nsName := "inspect"
	meshName := "inspect"

	BeforeAll(func() {
		err := NewClusterSetup().
			Install(NamespaceWithSidecarInjection(nsName)).
			Install(MeshKubernetes(meshName)).
			Install(democlient.Install(democlient.WithNamespace(nsName), democlient.WithMesh(meshName))).
			Setup(kubernetes.Cluster)
		Expect(err).ToNot(HaveOccurred())
	})

	E2EAfterAll(func() {
		Expect(kubernetes.Cluster.TriggerDeleteNamespace(nsName)).To(Succeed())
		Expect(kubernetes.Cluster.DeleteMesh(meshName)).To(Succeed())
	})

	It("should return bad request on invalid name(#4985)", func() {
		_, err := kubernetes.Cluster.GetKumactlOptions().RunKumactlAndGetOutput("inspect", "dataplane", "-m", meshName, "dummy-name", "--type=config-dump")
		Expect(err).To(HaveOccurred())
		Expect(err.Error()).To(ContainSubstring(`Bad Request (name "dummy-name" must include namespace after the dot, ex. "name.namespace")`))
	})

	It("should return envoy config_dump", func() {
		// Synchronize on the dataplanes coming up.
		Eventually(func(g Gomega) {
			dataplanes, err := kubernetes.Cluster.GetKumactlOptions().KumactlList("dataplanes", meshName)
			g.Expect(err).ToNot(HaveOccurred())
			// Dataplane names are generated, so we check for a partial match.
			g.Expect(dataplanes).Should(ContainElement(ContainSubstring("demo-client")))
		}, "10s", "250ms").Should(Succeed())

		podName, err := PodNameOfApp(kubernetes.Cluster, "demo-client", nsName)
		Expect(err).ToNot(HaveOccurred())
		dataplaneName := fmt.Sprintf("%s.%s", podName, nsName)
		stdout, err := kubernetes.Cluster.GetKumactlOptions().RunKumactlAndGetOutput("inspect", "dataplane", "-m", meshName, dataplaneName, "--type=config-dump")
		Expect(err).ToNot(HaveOccurred())

		Expect(stdout).To(ContainSubstring(fmt.Sprintf(`"name": "demo-client_%s_svc"`, nsName)))
		Expect(stdout).To(ContainSubstring(`"name": "inbound:passthrough:ipv4"`))
		Expect(stdout).To(ContainSubstring(`"name": "inbound:passthrough:ipv6"`))
		Expect(stdout).To(ContainSubstring(`"name": "kuma:envoy:admin"`))
		Expect(stdout).To(ContainSubstring(`"name": "outbound:passthrough:ipv4"`))
		Expect(stdout).To(ContainSubstring(`"name": "outbound:passthrough:ipv6"`))
	})
}

==> kumactl-2.5.2.tar.gz: kuma-2.5.2/test/e2e_env/kubernetes/inspect/inspect.go <==
package inspect

import (
	"encoding/json"
	"fmt"
	"io"
	"net/http"

	. "github.com/onsi/ginkgo/v2"
	. "github.com/onsi/gomega"

	"github.com/kumahq/kuma/api/openapi/types"
	. "github.com/kumahq/kuma/test/framework"
	"github.com/kumahq/kuma/test/framework/deployments/democlient"
	"github.com/kumahq/kuma/test/framework/envs/kubernetes"
)

func Inspect() {
	nsName := "inspect"
	meshName := "inspect"

	BeforeAll(func() {
		err := NewClusterSetup().
			Install(NamespaceWithSidecarInjection(nsName)).
			Install(MeshKubernetes(meshName)).
			Install(democlient.Install(democlient.WithNamespace(nsName), democlient.WithMesh(meshName))).
			Setup(kubernetes.Cluster)
		Expect(err).ToNot(HaveOccurred())
	})

	E2EAfterAll(func() {
		Expect(kubernetes.Cluster.TriggerDeleteNamespace(nsName)).To(Succeed())
		Expect(kubernetes.Cluster.DeleteMesh(meshName)).To(Succeed())
	})

	It("should return bad request on invalid name(#4985)", func() {
		_, err := kubernetes.Cluster.GetKumactlOptions().RunKumactlAndGetOutput("inspect", "dataplane", "-m", meshName, "dummy-name", "--type=config-dump")
		Expect(err).To(HaveOccurred())
		Expect(err.Error()).To(ContainSubstring(`Bad Request (invalid format: name "dummy-name" must include namespace after the dot, ex. "name.namespace")`))
	})

	It("should return envoy config_dump", func() {
		// Synchronize on the dataplanes coming up.
		Eventually(func(g Gomega) {
			dataplanes, err := kubernetes.Cluster.GetKumactlOptions().KumactlList("dataplanes", meshName)
			g.Expect(err).ToNot(HaveOccurred())
			// Dataplane names are generated, so we check for a partial match.
			g.Expect(dataplanes).Should(ContainElement(ContainSubstring("demo-client")))
		}, "10s", "250ms").Should(Succeed())

		podName, err := PodNameOfApp(kubernetes.Cluster, "demo-client", nsName)
		Expect(err).ToNot(HaveOccurred())
		dataplaneName := fmt.Sprintf("%s.%s", podName, nsName)
		stdout, err := kubernetes.Cluster.GetKumactlOptions().RunKumactlAndGetOutput("inspect", "dataplane", "-m", meshName, dataplaneName, "--type=config-dump")
		Expect(err).ToNot(HaveOccurred())

		Expect(stdout).To(ContainSubstring(fmt.Sprintf(`"name": "demo-client_%s_svc"`, nsName)))
		Expect(stdout).To(ContainSubstring(`"name": "inbound:passthrough:ipv4"`))
		Expect(stdout).To(ContainSubstring(`"name": "inbound:passthrough:ipv6"`))
		Expect(stdout).To(ContainSubstring(`"name": "kuma:envoy:admin"`))
		Expect(stdout).To(ContainSubstring(`"name": "outbound:passthrough:ipv4"`))
		Expect(stdout).To(ContainSubstring(`"name": "outbound:passthrough:ipv6"`))
	})

	DescribeTable("should execute inspect of policies",
		func(policyType string, policyName string) {
			Eventually(func(g Gomega) {
				r, err := http.Get(kubernetes.Cluster.GetKuma().GetAPIServerAddress() + fmt.Sprintf("/meshes/%s/timeouts/timeout-all-%s/_resources/dataplanes", meshName, meshName))
				g.Expect(err).ToNot(HaveOccurred())
				defer r.Body.Close()
				g.Expect(r).To(HaveHTTPStatus(200))

				body, err := io.ReadAll(r.Body)
				g.Expect(err).ToNot(HaveOccurred())
				result := types.InspectDataplanesForPolicyResponse{}
				g.Expect(json.Unmarshal(body, &result)).To(Succeed())

				g.Expect(result.Items).To(HaveLen(1))
				g.Expect(result.Total).To(Equal(1))
				g.Expect(result.Items[0].Name).To(HavePrefix("demo-client-"))
			}, "30s", "1s").Should(Succeed())
		},
		Entry("of dataplanes", "timeouts", fmt.Sprintf("timeout-all-%s", meshName)),
	)
}
